@@ -8,8 +8,10 @@ from typing import Dict, Any, Union, List, Optional
 
 import pandas as pd
 import pytz
+from aiohttp import ClientResponse
 from pandas import DataFrame, to_datetime, bdate_range
 from pandas_market_calendars import get_calendar
+from requests import Response
 
 
 def coalesce(*args):
@@ -195,3 +197,24 @@ def create_market_dates_between(start: date, end: date, name: str = 'NYSE') -> L
     """
     return [dt.date() for dt in
             to_datetime(get_calendar(name).schedule(start_date=start, end_date=end).index).to_list()]
+
+
+async def build_response_obj(aio_response: ClientResponse) -> Response:
+    """
+    Construct a requests Response object from an aiohttp Client Response object
+
+    Args:
+        aio_response (ClientResponse): Response object from aiohttp
+
+    Returns:
+        Response: A requests Response object
+    """
+    content = await aio_response.content.read()
+
+    response = Response()
+    response._content = content
+    response.url = str(aio_response.url)
+    response.status_code = aio_response.status
+    headers = {row[0]: row[1] for row in aio_response.headers.items()}
+    response.headers = headers
+    return response
